# Build Guide Overview
Building periodic-compatible web components is super easy as is converting existing components! The normal process looks like this:
* Create a Github repository to house your component set
* Create your components as you normally would
* Using the `periodic` CLI tool
 * Initialize and create a `periodic.json` file
 * Login to the periodic registry
 * Register your component set

## Polymer Components
Currently, by default, the Polymer platform is installed to `components/polymer/polymer-master`. When someone users `periodic` to install your web component set, it will install to `components/<username>/<componentsetname>`.
This puts your components three directories away from `components/` so you'll need to make sure that your `<link>` points to `../../../polymer/polymer-master/polymer.html`.

## Assets
Every component contains various assets which will need to be defined in `periodic.json`. Example:
```JSON
"assets": [
  "periodic-masonry.html",
  "periodic-masonry.js",
  "periodic-masonry.css"
]
```

## Dependencies
Dependencies must be detailed in `periodic.json` for both `polymer` and any web components that your component is dependent on:
```JSON
"dependencies": [
   "polymer",
   "periodic-masonry"
]
```

NOTE: Dependencies are not currently supported but are planned to be a part of the 1.0 release.

## Versioning
periodic uses [Semantic Versioning](http://semver.org) and your components are expected to do the same.

# Build Tutorial
Let's assume going into this tutorial that we already have a few components which we believe add awesome functionality to any web application. Before doing anything, we want to add these components to what we call a component set -- a sort of packaging for our components.
We can do this by creating a Github repository to store our component set. In our example, we will name our two components `awesome-a` and `awesome-b`.
Additionally, we will call our component set `awesome-components` which will be found at the fictional Github repository, `http://github.com/awesomeco/awesome-components`.

## Getting Started
Next we create directory in the project root that will house our components:
```Bash
$ mkdir registry
```

Here, we call the directory `registry` to denote that these components are to be used with the periodic registry but you can call this container directory whatever you wish.
Next, we build out our two components until our directory/file structure looks like this:
```
| project-folder
    |- registry
        |- awesome-a
            |- awesome-a.html
            |- awesome-a.css
            |- awesome-a.js
        |- awesome-b
            |- awesome-b.html
            |- awesome-b.css
            |- awesome-b.js
    |- periodic.json
```
 
Note: You most likely don't have a `periodic.json` quite yet and that's fine; well get to that now.

## Initializing our registry configuration
We can now initalize and create our `periodic.json` file which the periodic registry will use when determining the location of our components and their specific assets. While we can create and edit our configuration manually, `periodic` offers a nice wizard to aid us:
```Bash
$ pm init
```

This init process will first ask you for the container directory that is home to your components. In our example above, we used `registry/`. Once `periodic` knows about this directory, it will automatically find your current components and their assets. Use the space bar to select/de-select components or assets you do not want included. Not including them will prevent them from being retrievable by `periodic`.

## Registering our component set
The final step is registering our component set, making it available to all periodic users. This can be done by simply doing:
```Bash
$ pm register
```
and answering any questions presented.

Note: You will be asked to login via your Github account